@@ -143,12 +143,16 @@ func (r *ReconcileFileIntegrity) handleDefaultConfigMaps(logger logr.Logger, f *
 			return nil, scriptsUpdated, err
 		}
 		return nil, scriptsUpdated, nil
-	} else if _, ok := confCm.Data[common.DefaultConfDataKey]; !ok {
-		// we had the configMap but its data was missing for some reason, so restore it.
-		if err := r.client.Update(context.TODO(), defaultAIDEConfigMap(f.Name)); err != nil {
-			return nil, scriptsUpdated, err
+	} else {
+		_, hasData := confCm.Data[common.DefaultConfDataKey]
+		_, hasOwner := confCm.Labels[common.IntegrityOwnerLabelKey]
+		if !hasData || !hasOwner {
+			// we had the configMap but its data or owner label was missing, so restore it.
+			if err := r.client.Update(context.TODO(), defaultAIDEConfigMap(f.Name)); err != nil {
+				return nil, scriptsUpdated, err
+			}
+			return nil, scriptsUpdated, nil
 		}
-		return nil, scriptsUpdated, nil
 	}
 
 	return confCm, scriptsUpdated, nil
@@ -589,17 +593,17 @@ func aidePauseScript() *corev1.ConfigMap {
 			Namespace: common.FileIntegrityNamespace,
 		},
 		Data: map[string]string{
-			"pause.sh": aidePauseContainerScript,
+			common.AidePauseScriptKey: aidePauseContainerScript,
 		},
 	}
 }
 
 func dataMatchesReinitScript(cm *corev1.ConfigMap) bool {
-	return configMapKeyDataMatches(cm, aideReinitScript(), common.DefaultConfDataKey)
+	return configMapKeyDataMatches(cm, aideReinitScript(), common.AideScriptKey)
 }
 
 func dataMatchesPauseScript(cm *corev1.ConfigMap) bool {
-	return configMapKeyDataMatches(cm, aidePauseScript(), common.DefaultConfDataKey)
+	return configMapKeyDataMatches(cm, aidePauseScript(), common.AidePauseScriptKey)
 }
 
 func configMapKeyDataMatches(cm1, cm2 *corev1.ConfigMap, key string) bool {
@@ -847,6 +851,10 @@ func aideDaemonset(dsName string, fi *fileintegrityv1alpha1.FileIntegrity) *apps
 	}
 }
 
+func getMaxBackups(fi *fileintegrityv1alpha1.FileIntegrity) string {
+	return strconv.Itoa(fi.Spec.Config.MaxBackups)
+}
+
 func getGracePeriod(fi *fileintegrityv1alpha1.FileIntegrity) string {
 	gracePeriod := fi.Spec.Config.GracePeriod
 	if gracePeriod < 10 {
@@ -867,6 +875,7 @@ func daemonArgs(dsName string, fi *fileintegrityv1alpha1.FileIntegrity) []string
 		"--namespace=" + fi.Namespace,
 		"--interval=" + getGracePeriod(fi),
 		"--debug=" + getDebug(fi),
+		"--maxbackups=" + getMaxBackups(fi),
 		"--aideconfigdir=/config",
 		//"--pprof=true",
 	}
