@@ -680,6 +680,35 @@ func updateFileIntegrityConfig(t *testing.T, f *framework.Framework, integrityNa
 	}
 }
 
+func removeFileIntegrityConfigMapLabel(t *testing.T, f *framework.Framework, integrityName, namespace string) {
+	var lastErr error
+	pollErr := wait.PollImmediate(time.Second, 2*time.Minute, func() (bool, error) {
+		confMap := &corev1.ConfigMap{}
+		err := f.Client.Get(goctx.TODO(), types.NamespacedName{Name: integrityName, Namespace: namespace}, confMap)
+		if err != nil {
+			lastErr = err
+			return false, nil
+		}
+
+		// Remove the label, keep the aide-conf tag.
+		confMapCopy := confMap.DeepCopy()
+		confMapCopy.Labels = nil
+		confMapCopy.Labels = map[string]string{
+			"file-integrity.openshift.io/aide-conf": "",
+		}
+
+		err = f.Client.Update(goctx.TODO(), confMapCopy)
+		if err != nil {
+			lastErr = err
+			return false, nil
+		}
+		return true, nil
+	})
+	if pollErr != nil {
+		t.Errorf("Error updating configMap with a nil label: (%s) (%s)", pollErr, lastErr)
+	}
+}
+
 func reinitFileIntegrityDatabase(t *testing.T, f *framework.Framework, integrityName, namespace string, interval, timeout time.Duration) {
 	var lastErr error
 	pollErr := wait.PollImmediate(interval, timeout, func() (bool, error) {
@@ -1020,6 +1049,20 @@ func pollUntilConfigMapExists(t *testing.T, f *framework.Framework, namespace, n
 	return data, err
 }
 
+func pollUntilConfigMapHasLabel(t *testing.T, f *framework.Framework, namespace, name, labelName string, interval, timeout time.Duration) error {
+	return wait.PollImmediate(interval, timeout, func() (bool, error) {
+		cm, getErr := f.KubeClient.CoreV1().ConfigMaps(namespace).Get(goctx.TODO(), name, metav1.GetOptions{})
+		if getErr != nil {
+			return false, nil
+		}
+		_, ok := cm.Labels[labelName]
+		if !ok {
+			return false, nil
+		}
+		return true, nil
+	})
+}
+
 func containsUncompressedScanFailLog(data map[string]string) bool {
 	content, ok := data[common.IntegrityLogContentKey]
 	if !ok {
@@ -1179,6 +1222,21 @@ func confirmRemovedLegacyReinitFile(t *testing.T, ctx *framework.Context, f *fra
 	return waitForPod(containerCompleted(t, f.KubeClient, pod.Name, namespace, 1))
 }
 
+// tests for a set of re-init backups when MaxBackups is set to 1.
+func confirmMaxBackupFiles(t *testing.T, ctx *framework.Context, f *framework.Framework, node, namespace string) error {
+	pod := privPodOnNode(namespace, "test-backup-pod", node, "test `ls -1 /hostroot/etc/kubernetes/aide.db.gz.backup-* | wc -l` -eq 1")
+	if err := f.Client.Create(goctx.TODO(), pod, &framework.CleanupOptions{
+		TestContext:   ctx,
+		Timeout:       cleanupTimeout,
+		RetryInterval: cleanupRetryInterval,
+	}); err != nil {
+		return err
+	}
+
+	// We expect the test command to return 0 when there's only one aide.db.gz backup
+	return waitForPod(containerCompleted(t, f.KubeClient, pod.Name, namespace, 0))
+}
+
 func getTestMcfg(t *testing.T) *mcfgv1.MachineConfig {
 	mode := 420
 	trueish := true
@@ -1294,6 +1352,16 @@ func getFiDsPods(f *framework.Framework, fileIntegrityName, namespace string) (*
 	return pods, nil
 }
 
+func getFiOperatorPods(f *framework.Framework, namespace string) (*corev1.PodList, error) {
+	lo := metav1.ListOptions{LabelSelector: "name=file-integrity-operator"}
+	pods, err := f.KubeClient.CoreV1().Pods(namespace).List(goctx.TODO(), lo)
+	if err != nil {
+		return nil, err
+	}
+
+	return pods, nil
+}
+
 func waitUntilPodsAreGone(t *testing.T, c client.Client, pods *corev1.PodList, interval, timeout time.Duration) error {
 	return wait.PollImmediate(interval, timeout, func() (bool, error) {
 		for _, pod := range pods.Items {
@@ -1387,41 +1455,50 @@ func logContainerOutput(t *testing.T, f *framework.Framework, namespace, name st
 	if artifacts == "" {
 		return
 	}
+
 	pods, err := getFiDsPods(f, name, namespace)
 	if err != nil {
 		t.Logf("Warning: Error getting pods for container logging: %s", err)
-	} else {
-		for _, pod := range pods.Items {
-			for _, con := range containers {
-				logOpts := &corev1.PodLogOptions{}
-				if con != "self" {
-					logOpts.Container = con
+		return
+	}
+	operatorPods, err := getFiOperatorPods(f, namespace)
+	if err != nil {
+		t.Logf("Warning: Error getting pods for container logging: %s", err)
+		return
+	}
+
+	pods.Items = append(operatorPods.Items)
+
+	for _, pod := range pods.Items {
+		for _, con := range containers {
+			logOpts := &corev1.PodLogOptions{}
+			if con != "self" {
+				logOpts.Container = con
+			}
+			req := f.KubeClient.CoreV1().Pods(namespace).GetLogs(pod.Name, logOpts)
+			podLogs, err := req.Stream(goctx.TODO())
+			if err != nil {
+				// Silence this error if the container is not valid for the pod
+				if !kerr.IsBadRequest(err) {
+					t.Logf("error getting logs for %s/%s: reason: %v, err: %v", pod.Name, con, kerr.ReasonForError(err), err)
 				}
-				req := f.KubeClient.CoreV1().Pods(namespace).GetLogs(pod.Name, logOpts)
-				podLogs, err := req.Stream(goctx.TODO())
+				continue
+			}
+			buf := new(bytes.Buffer)
+			_, err = io.Copy(buf, podLogs)
+			if err != nil {
+				t.Logf("error copying logs for %s/%s: %v", pod.Name, con, err)
+				continue
+			}
+			logs := buf.String()
+			if len(logs) == 0 {
+				t.Logf("no logs for %s/%s", pod.Name, con)
+			} else {
+				err := writeToArtifactsDir(artifacts, name, pod.Name, con, logs)
 				if err != nil {
-					// Silence this error if the container is not valid for the pod
-					if !kerr.IsBadRequest(err) {
-						t.Logf("error getting logs for %s/%s: reason: %v, err: %v", pod.Name, con, kerr.ReasonForError(err), err)
-					}
-					continue
-				}
-				buf := new(bytes.Buffer)
-				_, err = io.Copy(buf, podLogs)
-				if err != nil {
-					t.Logf("error copying logs for %s/%s: %v", pod.Name, con, err)
-					continue
-				}
-				logs := buf.String()
-				if len(logs) == 0 {
-					t.Logf("no logs for %s/%s", pod.Name, con)
+					t.Logf("error writing logs for %s/%s: %v", pod.Name, con, err)
 				} else {
-					err := writeToArtifactsDir(artifacts, name, pod.Name, con, logs)
-					if err != nil {
-						t.Logf("error writing logs for %s/%s: %v", pod.Name, con, err)
-					} else {
-						t.Logf("wrote logs for %s/%s", pod.Name, con)
-					}
+					t.Logf("wrote logs for %s/%s", pod.Name, con)
 				}
 			}
 		}
